@@ -14,6 +14,7 @@ from    loguru                  import logger
 import  pudb
 import  json
 import  os
+import  inspect
 
 class env:
     '''
@@ -35,9 +36,23 @@ class env:
             'port'      : 7900,
             'host'      : '0.0.0.0'
         }
-        self.DEBUG      = logger.debug
-        self.INFO       = logger.info
-        self.ERROR      = logger.error
+
+    def DEBUG(self, *args, **kwargs):
+        level   : int   = 1
+        for k,v in kwargs.items():
+            if k == 'level' : level = v
+        if int(self.options.verbosity) >= level:
+            logger.opt(depth=1).debug(*args)
+
+    def INFO(self, *args, **kwargs):
+        level   : int   = 1
+        for k,v in kwargs.items():
+            if k == 'level' : level = v
+        if int(self.options.verbosity) >= level:
+            logger.opt(depth=1).info(*args)
+
+    def ERROR(self, *args):
+        logger.opt(depth=1).error(*args)
 
     @property
     def options(self):
